@@ -1,7 +1,7 @@
-pub mod data;
+pub mod models;
 pub mod opts;
 
-pub use data::*;
+pub use models::*;
 pub use opts::*;
 
 /// Allows easier construction of filter functions for multiple api endpoints
