@@ -29,11 +29,11 @@ pub struct ContainerInfo {
     pub labels: Labels,
     pub names: Vec<String>,
     pub ports: Vec<Port>,
-    pub state: String,
+    pub state: ContainerStatus,
     pub status: String,
     pub size_rw: Option<i64>,
     pub size_root_fs: Option<i64>,
-    pub mounts: Vec<Mount>,
+    pub mounts: Option<Vec<Mount>>,
 }
 
 #[derive(Clone, Debug, Serialize, Deserialize)]
@@ -66,7 +66,7 @@ pub struct ContainerDetails {
     pub size_rw: Option<i64>,
     pub size_root_fs: Option<i64>,
     pub mounts: Vec<MountPoint>,
-    pub config: ContainerConfig,
+    pub config: Option<ContainerConfig>,
     pub network_settings: NetworkSettings,
 }
 
@@ -230,6 +230,7 @@ pub struct MountPoint {
 #[serde(rename_all = "lowercase")]
 pub enum ContainerStatus {
     Created,
+    Configured,
     Restarting,
     Running,
     Removing,
@@ -243,6 +244,7 @@ impl AsRef<str> for ContainerStatus {
         use ContainerStatus::*;
         match &self {
             Created => "created",
+            Configured => "configured",
             Restarting => "restarting",
             Running => "running",
             Removing => "removing",
@@ -440,7 +442,7 @@ pub struct LogConfig {
     #[serde(rename = "Type")]
     pub type_: String,
     #[serde(rename = "Config")]
-    pub config: ConfigMap,
+    pub config: Option<ConfigMap>,
 }
 
 #[derive(Clone, Debug, Serialize, Deserialize)]
