@@ -397,6 +397,11 @@ impl ContainerOptsBuilder {
         working_dir: W => "WorkingDir"
     );
 
+    impl_vec_field!(
+        /// Specify a Vec of string values to customize labels for MLS systems, such as SELinux.
+        security_options: O => "HostConfig.SecurityOpt"
+    );
+
     impl_vec_field!(
         /// Specify any bind mounts, taking the form of `/some/host/path:/some/container/path`
         volumes: V => "HostConfig.Binds"
