@@ -62,7 +62,7 @@ pub struct RegistryAuthBuilder {
 
 impl RegistryAuthBuilder {
     /// The username used for authentication.
-    pub fn username<U>(&mut self, username: U) -> &mut Self
+    pub fn username<U>(mut self, username: U) -> Self
     where
         U: Into<String>,
     {
@@ -71,7 +71,7 @@ impl RegistryAuthBuilder {
     }
 
     /// The password used for authentication.
-    pub fn password<P>(&mut self, password: P) -> &mut Self
+    pub fn password<P>(mut self, password: P) -> Self
     where
         P: Into<String>,
     {
@@ -80,7 +80,7 @@ impl RegistryAuthBuilder {
     }
 
     /// The email addres used for authentication.
-    pub fn email<E>(&mut self, email: E) -> &mut Self
+    pub fn email<E>(mut self, email: E) -> Self
     where
         E: Into<String>,
     {
@@ -90,7 +90,7 @@ impl RegistryAuthBuilder {
 
     /// The server address of registry, should be a domain/IP without a protocol.
     /// Example: `10.92.0.1`, `docker.corp.local`
-    pub fn server_address<A>(&mut self, server_address: A) -> &mut Self
+    pub fn server_address<A>(mut self, server_address: A) -> Self
     where
         A: Into<String>,
     {
@@ -185,15 +185,15 @@ impl PullOptsBuilder {
     /// this causes all tags for the given image to be pulled.
     tag: T => "tag");
 
-    pub fn auth(&mut self, auth: RegistryAuth) -> &mut Self {
+    pub fn auth(mut self, auth: RegistryAuth) -> Self {
         self.auth = Some(auth);
         self
     }
 
-    pub fn build(&mut self) -> PullOpts {
+    pub fn build(self) -> PullOpts {
         PullOpts {
-            auth: self.auth.take(),
-            params: self.params.clone(),
+            auth: self.auth,
+            params: self.params,
         }
     }
 }
@@ -552,6 +552,62 @@ impl ClearCacheOptsBuilder {
     );
 }
 
+pub struct ImagePushOpts {
+    auth: Option<RegistryAuth>,
+    params: HashMap<&'static str, String>,
+}
+
+impl ImagePushOpts {
+    pub fn builder() -> ImagePushOptsBuilder {
+        ImagePushOptsBuilder::default()
+    }
+
+    pub fn serialize(&self) -> Option<String> {
+        if self.params.is_empty() {
+            None
+        } else {
+            Some(encoded_pairs(self.params.iter()))
+        }
+    }
+
+    pub(crate) fn auth_header(&self) -> Option<String> {
+        self.auth.clone().map(|a| a.serialize())
+    }
+}
+
+pub struct ImagePushOptsBuilder {
+    auth: Option<RegistryAuth>,
+    params: HashMap<&'static str, String>,
+}
+
+impl Default for ImagePushOptsBuilder {
+    fn default() -> Self {
+        Self {
+            auth: None,
+            params: [("tag", "latest".into())].into(),
+        }
+    }
+}
+
+impl ImagePushOptsBuilder {
+    impl_url_str_field!(
+        /// The tag to associate with the image on the registry.
+        tag: T => "tag"
+    );
+
+    pub fn auth(mut self, auth: RegistryAuth) -> Self {
+        self.auth = Some(auth);
+        self
+    }
+
+    pub fn build(self) -> ImagePushOpts {
+        ImagePushOpts {
+            auth: self.auth,
+            params: self.params,
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
