@@ -13,41 +13,39 @@ impl_api_ty!(Network => id);
 impl<'docker> Network<'docker> {
     impl_api_ep! { net: Network, resp
         Inspect -> &format!("/networks/{}", net.id)
-        Delete -> &format!("/network/{}", net.id)
+        Delete -> &format!("/networks/{}", net.id)
     }
 
     api_doc! { Network => Connect
-    /// Connect container to network.
+    /// Connect a container to a network.
     |
     pub async fn connect(&self, opts: &ContainerConnectionOpts) -> Result<()> {
-        self.do_connection("connect", opts).await
+        self.docker
+            .post(
+                &format!("/networks/{}/connect", self.id),
+                Payload::Json(opts.serialize()?),
+            )
+            .await.map(|_| ())
     }}
 
     api_doc! { Network => Disconnect
-    /// Disconnect container to network.
+    /// Disconnect a container from a network.
     |
-    pub async fn disconnect(&self, opts: &ContainerConnectionOpts) -> Result<()> {
-        self.do_connection("disconnect", opts).await
-    }}
-
-    async fn do_connection<S>(&self, segment: S, opts: &ContainerConnectionOpts) -> Result<()>
-    where
-        S: AsRef<str>,
-    {
+    pub async fn disconnect(&self, opts: &ContainerDisconnectionOpts) -> Result<()> {
         self.docker
             .post(
-                &format!("/networks/{}/{}", self.id, segment.as_ref()),
+                &format!("/networks/{}/disconnect", &self.id),
                 Payload::Json(opts.serialize()?),
             )
-            .await?;
-        Ok(())
-    }
+            .await
+            .map(|_| ())
+    }}
 }
 
 impl<'docker> Networks<'docker> {
     impl_api_ep! { __: Network, resp
         List -> "/networks"
-        Create -> "/network/create", resp.id
+        Create -> "/networks/create", resp.id
         Prune -> "/networks/prune"
     }
 }
