@@ -3,7 +3,7 @@
 
 use crate::{conn::Payload, Result};
 
-impl_api_ty!(Secret => name: N);
+impl_api_ty!(Secret => name);
 
 impl<'docker> Secret<'docker> {
     impl_api_ep! { secret: Secret, resp
@@ -20,7 +20,7 @@ impl<'docker> Secrets<'docker> {
     }
 }
 
-pub mod data {
+pub mod models {
     use crate::{
         api::{Driver, Labels, ObjectVersion},
         Error, Result,
@@ -86,22 +86,25 @@ pub mod data {
         }
 
         /// Set the driver of this secret.
-        pub fn set_driver(&mut self, driver: Driver) {
+        pub fn set_driver(mut self, driver: Driver) -> Self {
             self.driver = driver;
+            self
         }
 
         /// Set the templating driver of this secret.
-        pub fn set_templating(&mut self, driver: Driver) {
+        pub fn set_templating(mut self, driver: Driver) -> Self {
             self.templating = driver;
+            self
         }
 
         /// Add a label to this secret
-        pub fn add_label<K, V>(&mut self, key: K, val: V) -> Option<String>
+        pub fn add_label<K, V>(mut self, key: K, val: V) -> Self
         where
             K: Into<String>,
             V: Into<String>,
         {
-            self.labels.insert(key.into(), val.into())
+            self.labels.insert(key.into(), val.into());
+            self
         }
 
         pub fn serialize(&self) -> Result<String> {
@@ -134,7 +137,7 @@ pub mod data {
     }
 }
 
-pub use data::*;
+pub use models::*;
 
 pub mod opts {
     use crate::api::Filter;
