@@ -1,17 +1,17 @@
 #![cfg(feature = "swarm")]
 //! Manage and inspect services within a swarm.
-pub mod data;
+pub mod models;
 pub mod opts;
 
-pub use data::*;
+pub use models::*;
 pub use opts::*;
 
 use crate::{
-    conn::{Headers, Payload},
+    conn::{Headers, Payload, AUTH_HEADER},
     Result,
 };
 
-impl_api_ty!(Service => name: N);
+impl_api_ty!(Service => name);
 
 impl<'docker> Service<'docker> {
     api_doc! { Service => Create
@@ -20,7 +20,7 @@ impl<'docker> Service<'docker> {
     pub async fn create(&self, opts: &ServiceOpts) -> Result<ServiceCreateInfo> {
         let headers = opts
             .auth_header()
-            .map(|a| Headers::single("X-Registry-Auth", a));
+            .map(|a| Headers::single(AUTH_HEADER, a));
         self.docker
             .post_json_headers(
                 "/services/create",
