@@ -1,12 +1,12 @@
-pub mod data;
+pub mod models;
 pub mod opts;
 
-pub use data::*;
+pub use models::*;
 pub use opts::*;
 
 use crate::{util::url::construct_ep, Docker, Error, Result};
 
-use futures_util::stream::{Stream, TryStreamExt};
+use futures_util::{Stream, TryStreamExt};
 
 use std::{convert::TryFrom, io};
 
