@@ -1,13 +1,13 @@
 //! Create and manage persistent storage that can be attached to containers.
-pub mod data;
+pub mod models;
 pub mod opts;
 
-pub use data::*;
+pub use models::*;
 pub use opts::*;
 
 use crate::{conn::Payload, Result};
 
-impl_api_ty!(Volume => name: N);
+impl_api_ty!(Volume => name);
 
 impl<'docker> Volume<'docker> {
     impl_api_ep! {vol: Volume, resp
